/**************************************************************************/
/*  Klavaro - a flexible touch typing tutor                               */
/*  Copyright (C) 2005 - 2008  Felipe Castro                              */
/*                                                                        */
/*  This program is free software, licensed under the terms of the GNU    */
/*  General Public License as published by the Free Software Foundation,  */
/*  which is also included in this package, in a file named "COPYING".    */
/**************************************************************************/

/*
 * Interface functions
 */
gint basic_get_lesson (void);

void basic_set_lesson (gint lesson);

gunichar *basic_get_char_set (void);

gboolean basic_get_lesson_increased (void);

void basic_set_lesson_increased (gboolean state);

/*
 * Auxiliar functions
 */
void basic_init (void);

gint basic_init_char_set (void);

void basic_save_lesson (gchar * charset);

void basic_draw_lesson (void);

void basic_comment (gdouble accuracy);
